#!/usr/bin/env python3
import prompt


def welcome_user():
    print('Welcome to the Brain Games!')
    name = prompt.string('May I have your name? ')
    print(f'Hello, {name}!')
    return name


def game_over(answer, right_answer, name):
    print(
        f"'{answer}' is wrong answer ;(. Correct answer was '{right_answer}'.")
    print(f"Let's try again, {name}!")


def lets_try_again(name):
    print(f"Let's try again, {name}!")



import math
import random


rules = 'Find the greatest common divisor of given numbers.'


def run():
    first_number = random.randint(1, 100)
    second_number = random.randint(1, 100)
    correct_answer = math.gcd(first_number, second_number)
    question = f'{first_number} {second_number}'
    return question, correct_answer



import random


rules = 'What is the result of the expression?'


def find_correct_answer(first_number, second_number, operation):
    if operation == '+':
        return first_number + second_number
    elif operation == '-':
        return first_number - second_number
    elif operation == '*':
        return first_number * second_number


def run():
    first_number = random.randint(1, 100)
    second_number = random.randint(1, 100)
    operation = random.choice(['+', '-', '*'])
    correct_answer = find_correct_answer(first_number, second_number, operation)
    question = f'{first_number} {operation} {second_number}'
    return question, correct_answer



#!/usr/bin/env python3
from brain_games.game_engine import run_game
from brain_games.games import brain_progression


def main():
    run_game(brain_progression)


if __name__ == '__main__':
    main()



import random
from brain_games.games.brain_even import compare_answer


rules = 'Answer "yes" if given number is prime. Otherwise answer "no".'


def is_prime(a):
    if a % 2 == 0:
        return a == 2
    elif a == 1:
        return False
    d = 3
    while d * d <= a and a % d != 0:
        d += 2
    return d * d > a


def run():
    choice = [1, 2, 3, 4, 5, 7, 9, 11, 13, 15, 17,
              18, 19, 21, 22, 23, 29, 31, 37, 38, 39, 40, 41,
              43, 47, 53, 59, 61, 62, 63, 64, 65, 66, 67, 68,
              69, 71, 72, 73, 74, 76, 78, 79, 83, 84, 85, 86,
              89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100]
    question = random.choice(choice)
    correct_answer = compare_answer(is_prime(question))
    return question, correct_answer



from random import randint


rules = 'What number is missing in the progression?'
length_progression = randint(5, 10)
start = randint(1, 10)
step = randint(1, 10)
secret_number = randint(0, length_progression - 1)


def run():
    question = ''
    i = 0
    while i < length_progression:
        if question:
            question += ' '
        if i != secret_number:
            question = question + str((start + (step * i)))
            i += 1
        else:
            question += '..'
            correct_answer = str(start + (step * i))
            i += 1
    return question, correct_answer



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['brain_games', 'brain_games.games', 'brain_games.scripts']

package_data = \
{'': ['*']}

install_requires = \
['prompt>=0.4.1,<0.5.0']

entry_points = \
{'console_scripts': ['brain-calc = brain_games.scripts.brain_calc:main',
                     'brain-even = brain_games.scripts.brain_even:main',
                     'brain-games = brain_games.scripts.brain_games:main',
                     'brain-gcd = brain_games.scripts.brain_gcd:main',
                     'brain-prime = brain_games.scripts.brain_prime:main',
                     'brain-progression = '
                     'brain_games.scripts.brain_progression:main']}

setup_kwargs = {
    'name': 'pengue-brain-games',
    'version': '0.1.1',
    'description': '',
    'long_description': '### Hexlet tests and linter status:\n[![Actions Status](https://github.com/Pengue/python-project-49/workflows/hexlet-check/badge.svg)](https://github.com/Pengue/python-project-49/actions)\n[![Maintainability](https://api.codeclimate.com/v1/badges/26cbe53cff2aa1026fef/maintainability)](https://codeclimate.com/github/Pengue/python-project-49)\n\n# Brain Games. Level 1 project on [Hexlet](https://ru.hexlet.io/professions/python/projects/49), program: Python developer.\n\nInstallation:\n\n`pip install -i https://test.pypi.org/simple/ --extra-index-url https://pypi.org/simple/ pengue-brain-games`\n\n## Installing package and playing in brain-even\n<a href="https://asciinema.org/a/560367" target="_blank"><img src="https://asciinema.org/a/560367.svg" /></a>\n\n## Playing in brain-calc\n<a href="https://asciinema.org/a/560369" target="_blank"><img src="https://asciinema.org/a/560369.svg" /></a>\n\n## Playing in brain-gcd\n<a href="https://asciinema.org/a/560376" target="_blank"><img src="https://asciinema.org/a/560376.svg" /></a>\n\n## Playing in brain-progression\n<a href="https://asciinema.org/a/560350" target="_blank"><img src="https://asciinema.org/a/560350.svg" /></a>\n\n## Playing in brain-prime\n<a href="https://asciinema.org/a/560358" target="_blank"><img src="https://asciinema.org/a/560358.svg" /></a>',
    'author': 'Your Name',
    'author_email': 'you@example.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8.1,<4.0.0',
}


setup(**setup_kwargs)



import random


rules = 'Answer "yes" if the number is even, otherwise answer "no".'


def check_parity(number):
    if number % 2 == 0:
        return True
    return False


def compare_answer(parity):
    if parity is True:
        return 'yes'
    elif parity is False:
        return 'no'


def run():
    qustion = random.randint(1, 100)
    correct_answer = compare_answer(check_parity(qustion))
    return qustion, correct_answer



#!/usr/bin/env python3
import prompt
import brain_games.cli


max_score = 3


def run_game(game):
    name = brain_games.cli.welcome_user()
    print(game.rules)
    score = 0
    while score < max_score:
        question, correct_answer = game.run()
        print(f'Question: {question}')
        answer = prompt.string('Your answer: ')
        if answer != str(correct_answer):
            print(
                f"'{answer}' is wrong answer ;(.",
                f"Correct answer was '{correct_answer}'.",
            )
            print(f"Let's try again, {name}!")
            return
        print('Correct!')
        score += 1
    print(f'Congratulations, {name}!')
